#
# spec file for package cava
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           cava
Version:        0.10.3
Release:        1.1
Summary:        Console-based Audio Visualizer for Alsa
License:        MIT
Group:          Productivity/Multimedia/Sound/Visualization
URL:            https://github.com/karlstav/cava
Source:         https://github.com/karlstav/%{name}/archive/%{version}.tar.gz
BuildRequires:  alsa-devel
BuildRequires:  fftw3-devel
# Use system ini parser instead of building own lib
BuildRequires:  libiniparser-devel >= 4.0
BuildRequires:  libpulse-devel
BuildRequires:  libtool
BuildRequires:  ncurses-devel
BuildRequires:  pipewire-devel
# Installing the psf in a directory that comes from kbd
Requires:       kbd

%description
C.A.V.A. is a bar spectrum audio visualizer for the Linux terminal using ALSA, pulseaudio or fifo buffer for input.

%prep
%setup -q
./autogen.sh
%configure FONT_DIR="%{_datadir}/kbd/consolefonts"

%build
%make_build

%install
%make_install

%files
%license LICENSE
%doc README.md
%{_bindir}/cava
%dir %{_datadir}/kbd/
%dir %{_datadir}/kbd/consolefonts/
%{_datadir}/kbd/consolefonts/cava.psf

%changelog
* Tue Nov 26 2024 Michael Vetter <mvetter@suse.com>
- Update to 0.10.3:
  * added horizontal split view #575
  * Fix crash when using pulseaudio #569
  * Synchronized Sync (Mode 2026) #576
  * add android source code #552
* Tue May 14 2024 Michael Vetter <mvetter@suse.com>
- Update to 0.10.2:
  * fix source being ignored when using pipewire #557
  * fix stdlib.h not being included after iniparser upgrade #560
  * add waveform visualization #484
  * exit with error if pipewire loop creation fails #561
* Fri Feb  2 2024 Michael Vetter <mvetter@suse.com>
- Update to 0.10.1:
  * JACK support
  * default to pulseaudio before sndio
* Tue Jan  9 2024 Michael Vetter <mvetter@suse.com>
- Update to 0.10.0:
  * OSS input backend and general improved FreeBSD support
  * pipewire default if supported
  * noncurses is now default
* Fri Aug 25 2023 Michael Vetter <mvetter@suse.com>
- bsc#1214255: Additionally to libpulse-devel also buildrequire
  pipewire-devel to enable build with pipewire support
* Sun Aug 13 2023 Michael Vetter <mvetter@suse.com>
- Update to 0.9.1:
  * hardcoded pipewire include flags #519
  * default input wrongly set to alsa instead of pulseaudio/pipewire #518
* Sun Aug  6 2023 Michael Vetter <mvetter@suse.com>
- Update to 0.9.0:
  new:
  * glsl shader output
  * windows operating system support
  * gradient support in sdl output
  breaking:
  * some config options are now 0-100 instead of 0-1 due to windows
    ini not supporting floats
* Fri Nov  4 2022 Michael Vetter <mvetter@suse.com>
- Update to 0.8.3:
  bugfixes:
  * fix some calculations on x-axis label
  * cavacore: channels where sorted wrong according to doc
  * fix autosensing sometimes not working
  improvements:
  * improved response time by decreasing audio buffer size
  * add support for alacritty synchronized updates
  * brought EQ back by popular demand
  * added support for hex colors and gradient in noncurses mode
  * add configurable orientation of bars
* Mon Apr 25 2022 Michael Vetter <mvetter@suse.com>
- Update to 0.8.2:
  bugfixes:
  * fix buffer overflow in audio buffer when calling reset_buffer
    (used in fifo input)
  * cavacore: fix segfault when setting 0Hz lower cut off
  * framerate <= 1 msec wait was multiplied by 1000 instead of divided
    improvements:
  * cavacore: don't print to stdout or call exit, use error status
    flag in cava_plan instead
  * cavacore: add extern C construct for c++ compilers
  * add license in cavacore header file
  * remove build dependency on xxd, use incbin instead
* Wed Apr 20 2022 Michael Vetter <mvetter@suse.com>
- Update to 0.8.1:
  * fix critical bug where default config value caused always maxed
    out bars #447
* Tue Apr 12 2022 Michael Vetter <mvetter@suse.com>
- Update to 0.8.0:
  breaking changes:
  * split out core functionality in separate library cavacore
    see CAVACORE.md for details
  * removed ignore config option
  * merge gravity and integral config option to "noise reduction"
  improvements:
  * use double precision all the way, improves details in visualization.
  * increase buffer sizes for large sample rates 96k++
  * noise filters should now scale better with resolution and framerate
  * embed default config file and populate on first launch instead of installing it
  * Add new output format, noritake VFD bitmap
  bugfixes:
  * fixed some potential buffer overflows
  * fix some bugs in sdl output
* Tue Feb  1 2022 Michael Vetter <mvetter@suse.com>
- Update to 0.7.5:
  improvements:
  * added sdl output support
  * better smoothing on higher resolutions, better scaling
  bugfixes:
  * fixed buffer overflow in shmem input
  * fixed bug where freebsd was not detected as supported os during autoconf
  other:
  * removed bundled iniparser
* Wed May 19 2021 Michael Vetter <mvetter@suse.com>
- Update to 0.7.4:
  improvements:
  * added faster autosens at startup
  bugfixes:
  * better installation of custom console font
  * suppress error about vla parameter introduced in gcc11 or 10?
* Thu Oct  8 2020 Michael Vetter <mvetter@suse.com>
- Update to 0.7.3:
  Improvements:
  * Added Hann windowing and proper ring buffer (this improves visualisation
  significantly!)
  * Added mutex lock on write to fftw input buffers and fftw execute (this
    removes som glitches)
  * Improved portaudio audio input
  * #370 made timeout configurable
  * ncurses mode is now default again
  * #379 removed key controls from noncurses to fix strange beaviour
  * Added config option: x-axis scale (frequency) #289
  Bugfixes:
  * #375 shmem audio input
  * #377 small memory leak
  * #385 fix eq
* Thu Jul  2 2020 Michael Vetter <mvetter@suse.com>
- Update to 0.7.2:
  improvements:
  * added key controls for noncurses mode #364
  bugfixes:
  * fix drawing of background color for noncurses mode
  * fix install on macos #365
* Thu Jun 25 2020 Michael Vetter <mvetter@suse.com>
- Update to 0.7.1:
  improvements:
  * set default gradient colors instead of exiting when not defined.
  bugfixes:
  * minor memory leak in ncurses
  * fix warnings when building on macos
  * updated macos building instructions
* Wed May 27 2020 Michael Vetter <mvetter@suse.com>
- Update 0.7.0:
  Breaking changes:
  * Reworked noncurses output mode and made it default.
    The reworked noncurses mode uses a custom framebuffer technique that
    only draws changes per frame and only writes to the terminal once per
    frame. This results in far less cpu usage then ncurses. It is also
    free of the flickering that we see in ncurses mode #196
  * Colors are no longer set by default so hopefully cava will change
    color automatically in noncurses mode when using tools such as
    pywall #340 #181
  * Unfortunately html colors, gradient and key controls are not supported
    in noncurses.
  Other improvements:
  * separated bass, midtones and treble in to separate fftw operations
* Sun May  6 2018 mvetter@suse.com
- Update to 0.6.1:
  new features:
  * sndio backend
  bug fixes:
  * Fix fftw_complex usage, drastically improving visualization
  * better cleanup and exiting
  * added a check to see if pulseaudio is running
  * fixed bug preventing color in noncurses mode from working
  * Fix build errors and warnings if not using ncurses
  * Generally improved fifo input and raw output
* Mon Aug 28 2017 mvetter@suse.com
- Update to 0.6.0:
  * Autosens of low values (dynamic range)
  * Removed config parameter 'overshoot'
  * Removed config parameter 'mode'
  * New config parameter 'waves'
  * Changed config parameter 'style' to 'channels' (was either 'mono' or 'stereo' anyway)
  * Parameters 'integral' and 'gravity' are now in percentage
* Fri Aug 18 2017 mvetter@suse.com
- Update to 0.5.0:
  new features:
  * gradient
  bugfixes:
  * memory leak
  * increased config reload speed
  * raw output not goint to /dev/stdout
* Thu Apr 27 2017 mvetter@suse.com
- Update to 0.4.3:
  new features:
  * support for more colors in ncurses output.
  bugfixes:
  * fixed bug where sensing of low values was done even when no sound
  * fixed bug in raw output bit format check
  * add a check for too many bars >200
- Remove because contained in new version:
  * cava-remove-nested-functions.patch
  * cava-font.patch
* Tue Mar 28 2017 mvetter@suse.com
- Add cava-font.patch:
  Install cava.psf to have nice output on TTYs.
* Tue Mar 28 2017 mvetter@suse.com
- Add cava-remove-nested-functions.patch:
  Remove nested functions to prevent OBS executable stack warning.
* Wed Mar 22 2017 mvetter@suse.com
- Get rid of unnecessary passing of prefix
* Thu Mar 16 2017 mvetter@suse.com
- It needs libiniparser from version 4 onwards
* Thu Mar 16 2017 mvetter@suse.com
- Update to 0.4.2:
  * added auto pulseaudio source mode
  * pulsaudio is now default
  * cava is now cavamp
  * pushing 'r' now reloads audio
  * Added console title
  * added pulseadio support
  * added confg script
  * removed commanline argumets
  * added optional config path
  * added autosens feature
  * added setting of bar width, bar spacing and frequency bandwidth to config file.
  * autodetection of alsa loopback interface
- Use proper group
- Update description
* Tue Jul 28 2015 mvetter@suse.com
- Honor optflags
* Tue Jul 28 2015 mvetter@suse.com
- Creating initial package for version 0.3.2
